#
# spec file for package python-statsd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-statsd
Version:        4.0.1
Release:        1.2
Summary:        A simple statsd client
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/jsocol/pystatsd
Source:         https://files.pythonhosted.org/packages/source/s/statsd/statsd-%{version}.tar.gz
Patch0:         remove-nose.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
statsd is a front-end to Graphite. This is a Python client
for the statsd daemon.

%prep
%autosetup -p1 -n statsd-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# https://github.com/jsocol/pystatsd/pull/150
sed -i 's:import mock:from unittest import mock:' statsd/tests.py
%pytest statsd/tests.py

%files %{python_files}
%license LICENSE
%doc AUTHORS README.rst
%{python_sitelib}/statsd
%{python_sitelib}/statsd-%{version}.dist-info

%changelog
* Sun Nov 24 2024 Dirk Müller <dmueller@suse.com>
- update to 4.0.1:
  * Updated trove classifiers, see #174
- update to 4.0.0:
  * Updates support to Python 3.7 through 3.11.
  * Added `close()` method to UDP-based `StatsClient`.
  * Drops support for Python 2.
  * Using a timing decorator on an async function should now
    properly measure the execution time, instead of counting
    immediately. See #119.
* Tue Apr 19 2022 pgajdos@suse.com
- do not require python-mock for build
* Tue Oct  5 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add remove-nose.patch:
  * Use pytest for the testsuite, and switch to bare asserts.
* Sun Feb 24 2019 John Vandenberg <jayvdb@gmail.com>
- Activate the test suite
- Add built docs to %%doc
- Use fdupes
- Update to v3.3.0
  * Drop support for Python 2.5, 2.6, 3.2, 3.3
  * Add UnixSocketStatsClient
  * Add support for timedeltas in timing()
  * Fix timer decorator with partial functions
  * Remove ABCMeta metaclass (incompatible with Py3)
  * Refactor client module
  * Various doc updates
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Mar 23 2018 tbechtold@suse.com
- update to 3.2.2:
  - Use a monotomic timer to avoid clock adjustments (#96).
  - Test on Python 3.5 and 3.6.
  - Various doc updates.
* Tue Aug 22 2017 tbechtold@suse.com
- convert to singlespec
* Tue Feb 14 2017 jengelh@inai.de
- Description with neutral point of view
* Sun Dec  6 2015 tbechtold@suse.com
- Initial packaging (version 3.2.1)
